"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Channel:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelRequest,
        global___QueryChannelResponse] = ...

    Channels:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelsRequest,
        global___QueryChannelsResponse] = ...

    ConnectionChannels:grpc.UnaryUnaryMultiCallable[
        global___QueryConnectionChannelsRequest,
        global___QueryConnectionChannelsResponse] = ...

    ChannelClientState:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelClientStateRequest,
        global___QueryChannelClientStateResponse] = ...

    ChannelConsensusState:grpc.UnaryUnaryMultiCallable[
        global___QueryChannelConsensusStateRequest,
        global___QueryChannelConsensusStateResponse] = ...

    PacketCommitment:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketCommitmentRequest,
        global___QueryPacketCommitmentResponse] = ...

    PacketCommitments:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketCommitmentsRequest,
        global___QueryPacketCommitmentsResponse] = ...

    PacketReceipt:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketReceiptRequest,
        global___QueryPacketReceiptResponse] = ...

    PacketAcknowledgement:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketAcknowledgementRequest,
        global___QueryPacketAcknowledgementResponse] = ...

    PacketAcknowledgements:grpc.UnaryUnaryMultiCallable[
        global___QueryPacketAcknowledgementsRequest,
        global___QueryPacketAcknowledgementsResponse] = ...

    UnreceivedPackets:grpc.UnaryUnaryMultiCallable[
        global___QueryUnreceivedPacketsRequest,
        global___QueryUnreceivedPacketsResponse] = ...

    UnreceivedAcks:grpc.UnaryUnaryMultiCallable[
        global___QueryUnreceivedAcksRequest,
        global___QueryUnreceivedAcksResponse] = ...

    NextSequenceReceive:grpc.UnaryUnaryMultiCallable[
        global___QueryNextSequenceReceiveRequest,
        global___QueryNextSequenceReceiveResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Channel(self,
        request: global___QueryChannelRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelResponse: ...

    @abc.abstractmethod
    def Channels(self,
        request: global___QueryChannelsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelsResponse: ...

    @abc.abstractmethod
    def ConnectionChannels(self,
        request: global___QueryConnectionChannelsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryConnectionChannelsResponse: ...

    @abc.abstractmethod
    def ChannelClientState(self,
        request: global___QueryChannelClientStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelClientStateResponse: ...

    @abc.abstractmethod
    def ChannelConsensusState(self,
        request: global___QueryChannelConsensusStateRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryChannelConsensusStateResponse: ...

    @abc.abstractmethod
    def PacketCommitment(self,
        request: global___QueryPacketCommitmentRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketCommitmentResponse: ...

    @abc.abstractmethod
    def PacketCommitments(self,
        request: global___QueryPacketCommitmentsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketCommitmentsResponse: ...

    @abc.abstractmethod
    def PacketReceipt(self,
        request: global___QueryPacketReceiptRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketReceiptResponse: ...

    @abc.abstractmethod
    def PacketAcknowledgement(self,
        request: global___QueryPacketAcknowledgementRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketAcknowledgementResponse: ...

    @abc.abstractmethod
    def PacketAcknowledgements(self,
        request: global___QueryPacketAcknowledgementsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryPacketAcknowledgementsResponse: ...

    @abc.abstractmethod
    def UnreceivedPackets(self,
        request: global___QueryUnreceivedPacketsRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnreceivedPacketsResponse: ...

    @abc.abstractmethod
    def UnreceivedAcks(self,
        request: global___QueryUnreceivedAcksRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryUnreceivedAcksResponse: ...

    @abc.abstractmethod
    def NextSequenceReceive(self,
        request: global___QueryNextSequenceReceiveRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryNextSequenceReceiveResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Snapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    CHUNKS_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    format: builtins.int = ...
    chunks: builtins.int = ...
    hash: builtins.bytes = ...

    @property
    def metadata(self) -> global___Metadata: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        format : builtins.int = ...,
        chunks : builtins.int = ...,
        hash : builtins.bytes = ...,
        metadata : typing.Optional[global___Metadata] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunks",b"chunks",u"format",b"format",u"hash",b"hash",u"height",b"height",u"metadata",b"metadata"]) -> None: ...
global___Snapshot = Snapshot

class Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHUNK_HASHES_FIELD_NUMBER: builtins.int

    @property
    def chunk_hashes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        chunk_hashes : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chunk_hashes",b"chunk_hashes"]) -> None: ...
global___Metadata = Metadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Equivocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    HEIGHT_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    CONSENSUS_ADDRESS_FIELD_NUMBER: builtins.int
    height: builtins.int = ...
    power: builtins.int = ...
    consensus_address: typing.Text = ...

    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...

    def __init__(self,
        *,
        height : builtins.int = ...,
        time : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        power : builtins.int = ...,
        consensus_address : typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"time",b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"consensus_address",b"consensus_address",u"height",b"height",u"power",b"power",u"time",b"time"]) -> None: ...
global___Equivocation = Equivocation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .query_pb2 import *
class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Evidence:grpc.UnaryUnaryMultiCallable[
        global___QueryEvidenceRequest,
        global___QueryEvidenceResponse] = ...

    AllEvidence:grpc.UnaryUnaryMultiCallable[
        global___QueryAllEvidenceRequest,
        global___QueryAllEvidenceResponse] = ...


class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Evidence(self,
        request: global___QueryEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryEvidenceResponse: ...

    @abc.abstractmethod
    def AllEvidence(self,
        request: global___QueryAllEvidenceRequest,
        context: grpc.ServicerContext,
    ) -> global___QueryAllEvidenceResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.client.v1.client_pb2
import ibc.core.connection.v1.connection_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: typing.Text = ...

    def __init__(self,
        *,
        connection_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_id",b"connection_id"]) -> None: ...
global___QueryConnectionRequest = QueryConnectionRequest

class QueryConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    proof: builtins.bytes = ...

    @property
    def connection(self) -> ibc.core.connection.v1.connection_pb2.ConnectionEnd: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        connection : typing.Optional[ibc.core.connection.v1.connection_pb2.ConnectionEnd] = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"connection",b"connection",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection",b"connection",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryConnectionResponse = QueryConnectionResponse

class QueryConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryConnectionsRequest = QueryConnectionsRequest

class QueryConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTIONS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        connections : typing.Optional[typing.Iterable[ibc.core.connection.v1.connection_pb2.IdentifiedConnection]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connections",b"connections",u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___QueryConnectionsResponse = QueryConnectionsResponse

class QueryClientConnectionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CLIENT_ID_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...

    def __init__(self,
        *,
        client_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id"]) -> None: ...
global___QueryClientConnectionsRequest = QueryClientConnectionsRequest

class QueryClientConnectionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_PATHS_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def connection_paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    proof: builtins.bytes = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        connection_paths : typing.Optional[typing.Iterable[typing.Text]] = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_paths",b"connection_paths",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryClientConnectionsResponse = QueryClientConnectionsResponse

class QueryConnectionClientStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: typing.Text = ...

    def __init__(self,
        *,
        connection_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_id",b"connection_id"]) -> None: ...
global___QueryConnectionClientStateRequest = QueryConnectionClientStateRequest

class QueryConnectionClientStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IDENTIFIED_CLIENT_STATE_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    proof: builtins.bytes = ...

    @property
    def identified_client_state(self) -> ibc.core.client.v1.client_pb2.IdentifiedClientState: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        identified_client_state : typing.Optional[ibc.core.client.v1.client_pb2.IdentifiedClientState] = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"identified_client_state",b"identified_client_state",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"identified_client_state",b"identified_client_state",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryConnectionClientStateResponse = QueryConnectionClientStateResponse

class QueryConnectionConsensusStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    REVISION_NUMBER_FIELD_NUMBER: builtins.int
    REVISION_HEIGHT_FIELD_NUMBER: builtins.int
    connection_id: typing.Text = ...
    revision_number: builtins.int = ...
    revision_height: builtins.int = ...

    def __init__(self,
        *,
        connection_id : typing.Text = ...,
        revision_number : builtins.int = ...,
        revision_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection_id",b"connection_id",u"revision_height",b"revision_height",u"revision_number",b"revision_number"]) -> None: ...
global___QueryConnectionConsensusStateRequest = QueryConnectionConsensusStateRequest

class QueryConnectionConsensusStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    proof: builtins.bytes = ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        client_id : typing.Text = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"consensus_state",b"consensus_state",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryConnectionConsensusStateResponse = QueryConnectionConsensusStateResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.auth.v1beta1.auth_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BaseVestingAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_ACCOUNT_FIELD_NUMBER: builtins.int
    ORIGINAL_VESTING_FIELD_NUMBER: builtins.int
    DELEGATED_FREE_FIELD_NUMBER: builtins.int
    DELEGATED_VESTING_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    end_time: builtins.int = ...

    @property
    def base_account(self) -> cosmos.auth.v1beta1.auth_pb2.BaseAccount: ...

    @property
    def original_vesting(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def delegated_free(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    @property
    def delegated_vesting(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        base_account : typing.Optional[cosmos.auth.v1beta1.auth_pb2.BaseAccount] = ...,
        original_vesting : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        delegated_free : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        delegated_vesting : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        end_time : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_account",b"base_account",u"delegated_free",b"delegated_free",u"delegated_vesting",b"delegated_vesting",u"end_time",b"end_time",u"original_vesting",b"original_vesting"]) -> None: ...
global___BaseVestingAccount = BaseVestingAccount

class ContinuousVestingAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    start_time: builtins.int = ...

    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...

    def __init__(self,
        *,
        base_vesting_account : typing.Optional[global___BaseVestingAccount] = ...,
        start_time : builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account",u"start_time",b"start_time"]) -> None: ...
global___ContinuousVestingAccount = ContinuousVestingAccount

class DelayedVestingAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int

    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...

    def __init__(self,
        *,
        base_vesting_account : typing.Optional[global___BaseVestingAccount] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account"]) -> None: ...
global___DelayedVestingAccount = DelayedVestingAccount

class Period(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LENGTH_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    length: builtins.int = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        length : builtins.int = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"length",b"length"]) -> None: ...
global___Period = Period

class PeriodicVestingAccount(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BASE_VESTING_ACCOUNT_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    VESTING_PERIODS_FIELD_NUMBER: builtins.int
    start_time: builtins.int = ...

    @property
    def base_vesting_account(self) -> global___BaseVestingAccount: ...

    @property
    def vesting_periods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Period]: ...

    def __init__(self,
        *,
        base_vesting_account : typing.Optional[global___BaseVestingAccount] = ...,
        start_time : builtins.int = ...,
        vesting_periods : typing.Optional[typing.Iterable[global___Period]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"base_vesting_account",b"base_vesting_account",u"start_time",b"start_time",u"vesting_periods",b"vesting_periods"]) -> None: ...
global___PeriodicVestingAccount = PeriodicVestingAccount



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ibc.core.channel.v1.channel_pb2
import ibc.core.client.v1.client_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryChannelRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id"]) -> None: ...
global___QueryChannelRequest = QueryChannelRequest

class QueryChannelResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    proof: builtins.bytes = ...

    @property
    def channel(self) -> ibc.core.channel.v1.channel_pb2.Channel: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        channel : typing.Optional[ibc.core.channel.v1.channel_pb2.Channel] = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel",b"channel",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryChannelResponse = QueryChannelResponse

class QueryChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> None: ...
global___QueryChannelsRequest = QueryChannelsRequest

class QueryChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNELS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.channel.v1.channel_pb2.IdentifiedChannel]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        channels : typing.Optional[typing.Iterable[ibc.core.channel.v1.channel_pb2.IdentifiedChannel]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channels",b"channels",u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___QueryChannelsResponse = QueryChannelsResponse

class QueryConnectionChannelsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTION_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    connection: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        connection : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"connection",b"connection",u"pagination",b"pagination"]) -> None: ...
global___QueryConnectionChannelsRequest = QueryConnectionChannelsRequest

class QueryConnectionChannelsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNELS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def channels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.channel.v1.channel_pb2.IdentifiedChannel]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        channels : typing.Optional[typing.Iterable[ibc.core.channel.v1.channel_pb2.IdentifiedChannel]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channels",b"channels",u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___QueryConnectionChannelsResponse = QueryConnectionChannelsResponse

class QueryChannelClientStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id"]) -> None: ...
global___QueryChannelClientStateRequest = QueryChannelClientStateRequest

class QueryChannelClientStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    IDENTIFIED_CLIENT_STATE_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    proof: builtins.bytes = ...

    @property
    def identified_client_state(self) -> ibc.core.client.v1.client_pb2.IdentifiedClientState: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        identified_client_state : typing.Optional[ibc.core.client.v1.client_pb2.IdentifiedClientState] = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"identified_client_state",b"identified_client_state",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"identified_client_state",b"identified_client_state",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryChannelClientStateResponse = QueryChannelClientStateResponse

class QueryChannelConsensusStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    REVISION_NUMBER_FIELD_NUMBER: builtins.int
    REVISION_HEIGHT_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    revision_number: builtins.int = ...
    revision_height: builtins.int = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        revision_number : builtins.int = ...,
        revision_height : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"revision_height",b"revision_height",u"revision_number",b"revision_number"]) -> None: ...
global___QueryChannelConsensusStateRequest = QueryChannelConsensusStateRequest

class QueryChannelConsensusStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONSENSUS_STATE_FIELD_NUMBER: builtins.int
    CLIENT_ID_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    client_id: typing.Text = ...
    proof: builtins.bytes = ...

    @property
    def consensus_state(self) -> google.protobuf.any_pb2.Any: ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        consensus_state : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        client_id : typing.Text = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"consensus_state",b"consensus_state",u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"client_id",b"client_id",u"consensus_state",b"consensus_state",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryChannelConsensusStateResponse = QueryChannelConsensusStateResponse

class QueryPacketCommitmentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    sequence: builtins.int = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"sequence",b"sequence"]) -> None: ...
global___QueryPacketCommitmentRequest = QueryPacketCommitmentRequest

class QueryPacketCommitmentResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITMENT_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    commitment: builtins.bytes = ...
    proof: builtins.bytes = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        commitment : builtins.bytes = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitment",b"commitment",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryPacketCommitmentResponse = QueryPacketCommitmentResponse

class QueryPacketCommitmentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"pagination",b"pagination",u"port_id",b"port_id"]) -> None: ...
global___QueryPacketCommitmentsRequest = QueryPacketCommitmentsRequest

class QueryPacketCommitmentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMITMENTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def commitments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.channel.v1.channel_pb2.PacketState]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        commitments : typing.Optional[typing.Iterable[ibc.core.channel.v1.channel_pb2.PacketState]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commitments",b"commitments",u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___QueryPacketCommitmentsResponse = QueryPacketCommitmentsResponse

class QueryPacketReceiptRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    sequence: builtins.int = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"sequence",b"sequence"]) -> None: ...
global___QueryPacketReceiptRequest = QueryPacketReceiptRequest

class QueryPacketReceiptResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RECEIVED_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    received: builtins.bool = ...
    proof: builtins.bytes = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        received : builtins.bool = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"proof",b"proof",u"proof_height",b"proof_height",u"received",b"received"]) -> None: ...
global___QueryPacketReceiptResponse = QueryPacketReceiptResponse

class QueryPacketAcknowledgementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    SEQUENCE_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...
    sequence: builtins.int = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        sequence : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id",u"sequence",b"sequence"]) -> None: ...
global___QueryPacketAcknowledgementRequest = QueryPacketAcknowledgementRequest

class QueryPacketAcknowledgementResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACKNOWLEDGEMENT_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    acknowledgement: builtins.bytes = ...
    proof: builtins.bytes = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        acknowledgement : builtins.bytes = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"acknowledgement",b"acknowledgement",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryPacketAcknowledgementResponse = QueryPacketAcknowledgementResponse

class QueryPacketAcknowledgementsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"pagination",b"pagination",u"port_id",b"port_id"]) -> None: ...
global___QueryPacketAcknowledgementsRequest = QueryPacketAcknowledgementsRequest

class QueryPacketAcknowledgementsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACKNOWLEDGEMENTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def acknowledgements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[ibc.core.channel.v1.channel_pb2.PacketState]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        acknowledgements : typing.Optional[typing.Iterable[ibc.core.channel.v1.channel_pb2.PacketState]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height",u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"acknowledgements",b"acknowledgements",u"height",b"height",u"pagination",b"pagination"]) -> None: ...
global___QueryPacketAcknowledgementsResponse = QueryPacketAcknowledgementsResponse

class QueryUnreceivedPacketsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PACKET_COMMITMENT_SEQUENCES_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    @property
    def packet_commitment_sequences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        packet_commitment_sequences : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"packet_commitment_sequences",b"packet_commitment_sequences",u"port_id",b"port_id"]) -> None: ...
global___QueryUnreceivedPacketsRequest = QueryUnreceivedPacketsRequest

class QueryUnreceivedPacketsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCES_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def sequences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        sequences : typing.Optional[typing.Iterable[builtins.int]] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"sequences",b"sequences"]) -> None: ...
global___QueryUnreceivedPacketsResponse = QueryUnreceivedPacketsResponse

class QueryUnreceivedAcksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PACKET_ACK_SEQUENCES_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    @property
    def packet_ack_sequences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        packet_ack_sequences : typing.Optional[typing.Iterable[builtins.int]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"packet_ack_sequences",b"packet_ack_sequences",u"port_id",b"port_id"]) -> None: ...
global___QueryUnreceivedAcksRequest = QueryUnreceivedAcksRequest

class QueryUnreceivedAcksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEQUENCES_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int

    @property
    def sequences(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...

    @property
    def height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        sequences : typing.Optional[typing.Iterable[builtins.int]] = ...,
        height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"height",b"height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"height",b"height",u"sequences",b"sequences"]) -> None: ...
global___QueryUnreceivedAcksResponse = QueryUnreceivedAcksResponse

class QueryNextSequenceReceiveRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PORT_ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    port_id: typing.Text = ...
    channel_id: typing.Text = ...

    def __init__(self,
        *,
        port_id : typing.Text = ...,
        channel_id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"channel_id",b"channel_id",u"port_id",b"port_id"]) -> None: ...
global___QueryNextSequenceReceiveRequest = QueryNextSequenceReceiveRequest

class QueryNextSequenceReceiveResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NEXT_SEQUENCE_RECEIVE_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    PROOF_HEIGHT_FIELD_NUMBER: builtins.int
    next_sequence_receive: builtins.int = ...
    proof: builtins.bytes = ...

    @property
    def proof_height(self) -> ibc.core.client.v1.client_pb2.Height: ...

    def __init__(self,
        *,
        next_sequence_receive : builtins.int = ...,
        proof : builtins.bytes = ...,
        proof_height : typing.Optional[ibc.core.client.v1.client_pb2.Height] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof_height",b"proof_height"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"next_sequence_receive",b"next_sequence_receive",u"proof",b"proof",u"proof_height",b"proof_height"]) -> None: ...
global___QueryNextSequenceReceiveResponse = QueryNextSequenceReceiveResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.staking.v1beta1.staking_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class GenesisState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int
    LAST_TOTAL_POWER_FIELD_NUMBER: builtins.int
    LAST_VALIDATOR_POWERS_FIELD_NUMBER: builtins.int
    VALIDATORS_FIELD_NUMBER: builtins.int
    DELEGATIONS_FIELD_NUMBER: builtins.int
    UNBONDING_DELEGATIONS_FIELD_NUMBER: builtins.int
    REDELEGATIONS_FIELD_NUMBER: builtins.int
    EXPORTED_FIELD_NUMBER: builtins.int
    last_total_power: builtins.bytes = ...
    exported: builtins.bool = ...

    @property
    def params(self) -> cosmos.staking.v1beta1.staking_pb2.Params: ...

    @property
    def last_validator_powers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LastValidatorPower]: ...

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Validator]: ...

    @property
    def delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Delegation]: ...

    @property
    def unbonding_delegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]: ...

    @property
    def redelegations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.staking.v1beta1.staking_pb2.Redelegation]: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.staking.v1beta1.staking_pb2.Params] = ...,
        last_total_power : builtins.bytes = ...,
        last_validator_powers : typing.Optional[typing.Iterable[global___LastValidatorPower]] = ...,
        validators : typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Validator]] = ...,
        delegations : typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Delegation]] = ...,
        unbonding_delegations : typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.UnbondingDelegation]] = ...,
        redelegations : typing.Optional[typing.Iterable[cosmos.staking.v1beta1.staking_pb2.Redelegation]] = ...,
        exported : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegations",b"delegations",u"exported",b"exported",u"last_total_power",b"last_total_power",u"last_validator_powers",b"last_validator_powers",u"params",b"params",u"redelegations",b"redelegations",u"unbonding_delegations",b"unbonding_delegations",u"validators",b"validators"]) -> None: ...
global___GenesisState = GenesisState

class LastValidatorPower(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    POWER_FIELD_NUMBER: builtins.int
    address: typing.Text = ...
    power: builtins.int = ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        power : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address",u"power",b"power"]) -> None: ...
global___LastValidatorPower = LastValidatorPower



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import cosmos.distribution.v1beta1.distribution_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.distribution.v1beta1.distribution_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse

class QueryValidatorOutstandingRewardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryValidatorOutstandingRewardsRequest = QueryValidatorOutstandingRewardsRequest

class QueryValidatorOutstandingRewardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REWARDS_FIELD_NUMBER: builtins.int

    @property
    def rewards(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorOutstandingRewards: ...

    def __init__(self,
        *,
        rewards : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorOutstandingRewards] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> None: ...
global___QueryValidatorOutstandingRewardsResponse = QueryValidatorOutstandingRewardsResponse

class QueryValidatorCommissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validator_address",b"validator_address"]) -> None: ...
global___QueryValidatorCommissionRequest = QueryValidatorCommissionRequest

class QueryValidatorCommissionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    COMMISSION_FIELD_NUMBER: builtins.int

    @property
    def commission(self) -> cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission: ...

    def __init__(self,
        *,
        commission : typing.Optional[cosmos.distribution.v1beta1.distribution_pb2.ValidatorAccumulatedCommission] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commission",b"commission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commission",b"commission"]) -> None: ...
global___QueryValidatorCommissionResponse = QueryValidatorCommissionResponse

class QueryValidatorSlashesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    STARTING_HEIGHT_FIELD_NUMBER: builtins.int
    ENDING_HEIGHT_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    validator_address: typing.Text = ...
    starting_height: builtins.int = ...
    ending_height: builtins.int = ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...

    def __init__(self,
        *,
        validator_address : typing.Text = ...,
        starting_height : builtins.int = ...,
        ending_height : builtins.int = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ending_height",b"ending_height",u"pagination",b"pagination",u"starting_height",b"starting_height",u"validator_address",b"validator_address"]) -> None: ...
global___QueryValidatorSlashesRequest = QueryValidatorSlashesRequest

class QueryValidatorSlashesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SLASHES_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int

    @property
    def slashes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent]: ...

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...

    def __init__(self,
        *,
        slashes : typing.Optional[typing.Iterable[cosmos.distribution.v1beta1.distribution_pb2.ValidatorSlashEvent]] = ...,
        pagination : typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pagination",b"pagination",u"slashes",b"slashes"]) -> None: ...
global___QueryValidatorSlashesResponse = QueryValidatorSlashesResponse

class QueryDelegationRewardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    VALIDATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...
    validator_address: typing.Text = ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        validator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address",u"validator_address",b"validator_address"]) -> None: ...
global___QueryDelegationRewardsRequest = QueryDelegationRewardsRequest

class QueryDelegationRewardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REWARDS_FIELD_NUMBER: builtins.int

    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        rewards : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards"]) -> None: ...
global___QueryDelegationRewardsResponse = QueryDelegationRewardsResponse

class QueryDelegationTotalRewardsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address"]) -> None: ...
global___QueryDelegationTotalRewardsRequest = QueryDelegationTotalRewardsRequest

class QueryDelegationTotalRewardsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    REWARDS_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int

    @property
    def rewards(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.distribution.v1beta1.distribution_pb2.DelegationDelegatorReward]: ...

    @property
    def total(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        rewards : typing.Optional[typing.Iterable[cosmos.distribution.v1beta1.distribution_pb2.DelegationDelegatorReward]] = ...,
        total : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"rewards",b"rewards",u"total",b"total"]) -> None: ...
global___QueryDelegationTotalRewardsResponse = QueryDelegationTotalRewardsResponse

class QueryDelegatorValidatorsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address"]) -> None: ...
global___QueryDelegatorValidatorsRequest = QueryDelegatorValidatorsRequest

class QueryDelegatorValidatorsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VALIDATORS_FIELD_NUMBER: builtins.int

    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...

    def __init__(self,
        *,
        validators : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"validators",b"validators"]) -> None: ...
global___QueryDelegatorValidatorsResponse = QueryDelegatorValidatorsResponse

class QueryDelegatorWithdrawAddressRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DELEGATOR_ADDRESS_FIELD_NUMBER: builtins.int
    delegator_address: typing.Text = ...

    def __init__(self,
        *,
        delegator_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"delegator_address",b"delegator_address"]) -> None: ...
global___QueryDelegatorWithdrawAddressRequest = QueryDelegatorWithdrawAddressRequest

class QueryDelegatorWithdrawAddressResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    WITHDRAW_ADDRESS_FIELD_NUMBER: builtins.int
    withdraw_address: typing.Text = ...

    def __init__(self,
        *,
        withdraw_address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"withdraw_address",b"withdraw_address"]) -> None: ...
global___QueryDelegatorWithdrawAddressResponse = QueryDelegatorWithdrawAddressResponse

class QueryCommunityPoolRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryCommunityPoolRequest = QueryCommunityPoolRequest

class QueryCommunityPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POOL_FIELD_NUMBER: builtins.int

    @property
    def pool(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.DecCoin]: ...

    def __init__(self,
        *,
        pool : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.DecCoin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"pool",b"pool"]) -> None: ...
global___QueryCommunityPoolResponse = QueryCommunityPoolResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CommitInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    STORE_INFOS_FIELD_NUMBER: builtins.int
    version: builtins.int = ...

    @property
    def store_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StoreInfo]: ...

    def __init__(self,
        *,
        version : builtins.int = ...,
        store_infos : typing.Optional[typing.Iterable[global___StoreInfo]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"store_infos",b"store_infos",u"version",b"version"]) -> None: ...
global___CommitInfo = CommitInfo

class StoreInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    name: typing.Text = ...

    @property
    def commit_id(self) -> global___CommitID: ...

    def __init__(self,
        *,
        name : typing.Text = ...,
        commit_id : typing.Optional[global___CommitID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"commit_id",b"commit_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"commit_id",b"commit_id",u"name",b"name"]) -> None: ...
global___StoreInfo = StoreInfo

class CommitID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    VERSION_FIELD_NUMBER: builtins.int
    HASH_FIELD_NUMBER: builtins.int
    version: builtins.int = ...
    hash: builtins.bytes = ...

    def __init__(self,
        *,
        version : builtins.int = ...,
        hash : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"hash",b"hash",u"version",b"version"]) -> None: ...
global___CommitID = CommitID



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Minter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INFLATION_FIELD_NUMBER: builtins.int
    ANNUAL_PROVISIONS_FIELD_NUMBER: builtins.int
    inflation: typing.Text = ...
    annual_provisions: typing.Text = ...

    def __init__(self,
        *,
        inflation : typing.Text = ...,
        annual_provisions : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"annual_provisions",b"annual_provisions",u"inflation",b"inflation"]) -> None: ...
global___Minter = Minter

class Params(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    MINT_DENOM_FIELD_NUMBER: builtins.int
    INFLATION_RATE_CHANGE_FIELD_NUMBER: builtins.int
    INFLATION_MAX_FIELD_NUMBER: builtins.int
    INFLATION_MIN_FIELD_NUMBER: builtins.int
    GOAL_BONDED_FIELD_NUMBER: builtins.int
    BLOCKS_PER_YEAR_FIELD_NUMBER: builtins.int
    mint_denom: typing.Text = ...
    inflation_rate_change: typing.Text = ...
    inflation_max: typing.Text = ...
    inflation_min: typing.Text = ...
    goal_bonded: typing.Text = ...
    blocks_per_year: builtins.int = ...

    def __init__(self,
        *,
        mint_denom : typing.Text = ...,
        inflation_rate_change : typing.Text = ...,
        inflation_max : typing.Text = ...,
        inflation_min : typing.Text = ...,
        goal_bonded : typing.Text = ...,
        blocks_per_year : builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"blocks_per_year",b"blocks_per_year",u"goal_bonded",b"goal_bonded",u"inflation_max",b"inflation_max",u"inflation_min",b"inflation_min",u"inflation_rate_change",b"inflation_rate_change",u"mint_denom",b"mint_denom"]) -> None: ...
global___Params = Params



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Proof(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    LEAF_HASH_FIELD_NUMBER: builtins.int
    AUNTS_FIELD_NUMBER: builtins.int
    total: builtins.int = ...
    index: builtins.int = ...
    leaf_hash: builtins.bytes = ...

    @property
    def aunts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.bytes]: ...

    def __init__(self,
        *,
        total : builtins.int = ...,
        index : builtins.int = ...,
        leaf_hash : builtins.bytes = ...,
        aunts : typing.Optional[typing.Iterable[builtins.bytes]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"aunts",b"aunts",u"index",b"index",u"leaf_hash",b"leaf_hash",u"total",b"total"]) -> None: ...
global___Proof = Proof

class ValueOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    PROOF_FIELD_NUMBER: builtins.int
    key: builtins.bytes = ...

    @property
    def proof(self) -> global___Proof: ...

    def __init__(self,
        *,
        key : builtins.bytes = ...,
        proof : typing.Optional[global___Proof] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"proof",b"proof"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"proof",b"proof"]) -> None: ...
global___ValueOp = ValueOp

class DominoOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    KEY_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    key: typing.Text = ...
    input: typing.Text = ...
    output: typing.Text = ...

    def __init__(self,
        *,
        key : typing.Text = ...,
        input : typing.Text = ...,
        output : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"input",b"input",u"key",b"key",u"output",b"output"]) -> None: ...
global___DominoOp = DominoOp

class ProofOp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TYPE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    type: typing.Text = ...
    key: builtins.bytes = ...
    data: builtins.bytes = ...

    def __init__(self,
        *,
        type : typing.Text = ...,
        key : builtins.bytes = ...,
        data : builtins.bytes = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"key",b"key",u"type",b"type"]) -> None: ...
global___ProofOp = ProofOp

class ProofOps(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPS_FIELD_NUMBER: builtins.int

    @property
    def ops(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProofOp]: ...

    def __init__(self,
        *,
        ops : typing.Optional[typing.Iterable[global___ProofOp]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"ops",b"ops"]) -> None: ...
global___ProofOps = ProofOps



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.bank.v1beta1.bank_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MsgSend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    FROM_ADDRESS_FIELD_NUMBER: builtins.int
    TO_ADDRESS_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    from_address: typing.Text = ...
    to_address: typing.Text = ...

    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...

    def __init__(self,
        *,
        from_address : typing.Text = ...,
        to_address : typing.Text = ...,
        amount : typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"amount",b"amount",u"from_address",b"from_address",u"to_address",b"to_address"]) -> None: ...
global___MsgSend = MsgSend

class MsgSendResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgSendResponse = MsgSendResponse

class MsgMultiSend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    INPUTS_FIELD_NUMBER: builtins.int
    OUTPUTS_FIELD_NUMBER: builtins.int

    @property
    def inputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Input]: ...

    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.bank.v1beta1.bank_pb2.Output]: ...

    def __init__(self,
        *,
        inputs : typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Input]] = ...,
        outputs : typing.Optional[typing.Iterable[cosmos.bank.v1beta1.bank_pb2.Output]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"inputs",b"inputs",u"outputs",b"outputs"]) -> None: ...
global___MsgMultiSend = MsgMultiSend

class MsgMultiSendResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___MsgMultiSendResponse = MsgMultiSendResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .tx_pb2 import *
class MsgStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ConnectionOpenInit:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenInit,
        global___MsgConnectionOpenInitResponse] = ...

    ConnectionOpenTry:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenTry,
        global___MsgConnectionOpenTryResponse] = ...

    ConnectionOpenAck:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenAck,
        global___MsgConnectionOpenAckResponse] = ...

    ConnectionOpenConfirm:grpc.UnaryUnaryMultiCallable[
        global___MsgConnectionOpenConfirm,
        global___MsgConnectionOpenConfirmResponse] = ...


class MsgServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ConnectionOpenInit(self,
        request: global___MsgConnectionOpenInit,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenInitResponse: ...

    @abc.abstractmethod
    def ConnectionOpenTry(self,
        request: global___MsgConnectionOpenTry,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenTryResponse: ...

    @abc.abstractmethod
    def ConnectionOpenAck(self,
        request: global___MsgConnectionOpenAck,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenAckResponse: ...

    @abc.abstractmethod
    def ConnectionOpenConfirm(self,
        request: global___MsgConnectionOpenConfirm,
        context: grpc.ServicerContext,
    ) -> global___MsgConnectionOpenConfirmResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.auth.v1beta1.auth_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class QueryAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ADDRESS_FIELD_NUMBER: builtins.int
    address: typing.Text = ...

    def __init__(self,
        *,
        address : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"address",b"address"]) -> None: ...
global___QueryAccountRequest = QueryAccountRequest

class QueryAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACCOUNT_FIELD_NUMBER: builtins.int

    @property
    def account(self) -> google.protobuf.any_pb2.Any: ...

    def __init__(self,
        *,
        account : typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"account",b"account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"account",b"account"]) -> None: ...
global___QueryAccountResponse = QueryAccountResponse

class QueryParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...

    def __init__(self,
        ) -> None: ...
global___QueryParamsRequest = QueryParamsRequest

class QueryParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PARAMS_FIELD_NUMBER: builtins.int

    @property
    def params(self) -> cosmos.auth.v1beta1.auth_pb2.Params: ...

    def __init__(self,
        *,
        params : typing.Optional[cosmos.auth.v1beta1.auth_pb2.Params] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"params",b"params"]) -> None: ...
global___QueryParamsResponse = QueryParamsResponse
